#! /usr/bin/env bash
set -euo pipefail

if ! type aws >/dev/null 2>&1; then
  echo 'Not without awscli' >&2
  exit 1
fi
if ! type docker >/dev/null 2>&1; then
  echo 'Not without docker' >&2
  exit 1
fi
if ! type jq >/dev/null 2>&1; then
  echo 'Not without "jq"' >&2
  exit 1
fi

image_name="queue-worker"
image_tag="$BUILD_NUMBER"
local_image="${image_name}:${image_tag}"

docker build -t $local_image .

# dump the json response if these next few steps go awry
show_create_reg() {
  echo "EGAD, create-repository said <<${create_reg:-}>>" >&2
}
trap show_create_reg ERR

create_reg="$(aws ecr create-repository --repository-name queue-worker)"

ecr_name=$(jq -r .repository.repositoryUri <<AWS
$create_reg
AWS
)
trap - ERR

ecr_hostname=`echo "$ecr_name" | sed -e 's|/.*$||'`
# don't hang on to this JSON, if it bombs, we don't want to show it anyway
ecr_auth_password() {
    aws ecr get-authorization-token | \
    jq -r '.authorizationData[0].authorizationToken' | \
    base64 --decode | \
    cut -d: -f2
}

ecr_auth_password | docker login -u AWS --password-stdin $ecr_hostname

full_tag="${ecr_name}:${image_tag}"
docker tag  "$local_image" "$full_tag"
docker rmi  "$local_image"
docker push "$full_tag"
docker rmi  "$full_tag"
