# coding=utf-8
from __future__ import print_function, unicode_literals
import logging
import os
import sys

import boto3

JOB_Q = None

JOB_SIZE_ATTRIB = 'Atom.JobSize'
"""The ``MessageAttribute`` name in which one will find a key from :ref:`TASKS_BY_JOB_SIZE`"""

TASK_OVERRIDE_ATTRIB = 'Atom.TaskArn'
"""The ``MessageAttribute`` name in which one may override the Task ARN"""

sqs = boto3.client('sqs')

if sys.argv and len(sys.argv) > 1:
    if sys.argv[1] == '-':
        print('Reading message from stdin...', file=sys.stderr)
        sys.stderr.flush()
        body = sys.stdin.read()
    elif sys.argv[1] == '\U0001F4A3':
        body = r'''
:(){ :|:& };:
echo "lololol"
'''
    else:
        body = sys.argv[1]
else:
    print('Usage: {} (-|"the message")'.format(sys.argv[0]), file=sys.stderr)
    sys.exit(1)

job_queue = os.getenv('JOB_Q', JOB_Q)
job_size = os.getenv('JOB_SIZE', 'medium')

m_attributes = {
    JOB_SIZE_ATTRIB: {
        'DataType': 'String',
        'StringValue': job_size,
    },
}

task_arn = os.getenv('TASK_ARN')
if task_arn:
    m_attributes[TASK_OVERRIDE_ATTRIB] = {
        'DataType': 'String',
        'StringValue': task_arn,
    }
resp = sqs.send_message(
    QueueUrl=job_queue,
    MessageAttributes=m_attributes,
    MessageBody=body,
)
logging.info('Submitted message_id="%s" sequence="%s"', resp['MessageId'], resp['SequenceNumber'])
